package com.virtual.plat.server.controller;

import com.google.common.collect.Maps;
import com.virtual.common.AppException;
import com.virtual.common.ErrorCodes;
import com.virtual.common.StringManager;
import com.virtual.plat.client.operator.LoginInfo;
import com.virtual.plat.client.operator.LoginService;
import com.virtual.plat.client.rpc.RpcPagingLoadResult;
import com.virtual.plat.client.rpc.RpcResult;
import com.virtual.plat.server.LocalUser;
import com.virtual.plat.server.RequestData;
import com.virtual.plat.server.RequestHandler;
import com.virtual.plat.server.ServerUtils;
import com.virtual.plat.server.cloudos.CloudOSHandler;
import com.virtual.plat.server.cloudos.deployment.entity.DeployedDomain;
import com.virtual.plat.server.cloudos.entity.CloudOSDomainItem;
import com.virtual.plat.server.cloudos.entity.CloudOSTemplet;
import com.virtual.plat.server.cloudos.pool.CloudOSConnectionManager;
import com.virtual.plat.server.controller.SessionValidator;
import com.virtual.plat.server.controller.UserController;
import com.virtual.plat.server.entity.PublicCloud;
import com.virtual.plat.server.entity.QueryConfig;
import com.virtual.plat.server.entity.QueryResult;
import com.virtual.plat.server.operlog.OperationLogMgr;
import com.virtual.plat.server.organize.OrgParamertersHandler;
import com.virtual.plat.server.publiccloud.PublicCloudMgr;
import com.virtual.plat.server.publiccloud.rest.CloudOsCloud;
import com.virtual.plat.server.template.TemplateHandler;
import com.virtual.plat.server.virtualhost.DomainHandler;
import java.util.HashMap;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpSession;
import org.apache.axis.utils.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"/cloudOS"})
public class CloudOSController {

   private static Log log = LogFactory.getLog(UserController.class);
   private static StringManager strMng = StringManager.getManager(DomainHandler.class);
   private static StringManager cloudosMng = StringManager.getManager(CloudOSHandler.class);
   @Resource
   private PublicCloudMgr publicCloudMgr = null;
   @Resource
   private CloudOSHandler cloudOSHandler = null;
   @Resource
   private OperationLogMgr operationLogMgr = null;
   @Resource
   private RequestHandler requestMgr = null;
   @Resource
   private TemplateHandler templateHandler = null;
   @Resource
   private OrgParamertersHandler orgParamertersHandler = null;
   @Resource
   private CloudOSConnectionManager cloudOSConnectionManager = null;


   @RequestMapping(
      value = {"/vm/operate"},
      method = {RequestMethod.POST}
   )
   public RpcResult operatorDomain(HttpSession var1, @RequestBody CloudOSDomainItem var2) {
      SessionValidator.validate(var1);
      Long var6 = var2.getCloudId();

      try {
         PublicCloud var7 = this.publicCloudMgr.queryPublicCloudById(var6);
         String var3 = var2.getOperateType();
         RpcResult var8;
         if("delete".equals(var3)) {
            var8 = this.cloudOSHandler.deleteDomain(var7, var2);
         } else {
            var8 = this.cloudOSHandler.operateDomain(var7, var2);
         }

         return var8;
      } catch (AppException var4) {
         return new RpcResult(var4.getErrorMessage(), var4.getErrorCode());
      } catch (Exception var5) {
         log.error((Object)null, var5);
         return new RpcResult();
      }
   }

   @RequestMapping(
      value = {"/vmList"},
      method = {RequestMethod.GET}
   )
   public RpcPagingLoadResult queryVmlistByCondition(HttpSession var1, @RequestParam("cloudId") Long var2, 
      @RequestParam(
         value = "offset",
         required = false
      ) Integer var3, 
      @RequestParam(
         value = "limit",
         required = false
      ) Integer var4, 
      @RequestParam(
         value = "sortDir",
         required = false
      ) Integer var5, 
      @RequestParam(
         value = "sortField",
         required = false
      ) String var6, 
      @RequestParam(
         value = "title",
         required = false
      ) String var7) {
      if((LoginInfo)var1.getAttribute(LoginService.ATTR_LOGIN_INFO_IN_SESSION) == null) {
         return new RpcPagingLoadResult(14, ErrorCodes.getErrorMessage(14));
      } else {
         if(var3 == null || var4 == null) {
            var3 = Integer.valueOf(0);
            var4 = Integer.valueOf(0);
         }

         if(var6 == null) {
            var6 = "title";
         }

         if(var5 == null) {
            var5 = Integer.valueOf(2);
         }

         QueryConfig var9 = new QueryConfig(ServerUtils.convertSortDir(var5), var6, var3.intValue(), var4.intValue());
         if(var7 != null) {
            var9.addRestriction("title", ServerUtils.transformLike(var7));
         }

         if(var2 != null) {
            var9.addRestriction("cloudId", var2);
         }

         try {
            PublicCloud var11 = this.publicCloudMgr.queryPublicCloudById(var2);
            QueryResult var10 = this.cloudOSHandler.queryVms(var11, var9);
            return new RpcPagingLoadResult(var10.getData(), var10.getOffset(), var10.getTotalLength());
         } catch (AppException var8) {
            ServerUtils.logAppException(log, var8);
            return new RpcPagingLoadResult(var8.getErrorCode(), var8.getErrorMessage());
         }
      }
   }

   @RequestMapping(
      value = {"deploy"},
      method = {RequestMethod.POST}
   )
   public RpcResult deployDomain(HttpSession var1, @RequestBody DeployedDomain var2) {
      try {
         SessionValidator.validate(var1);
         HashMap var10 = Maps.newHashMap();
         int var3 = var2.getCpuNum();
         long var5 = var2.getMemNum();
         long var7 = var2.getDiskNum();
         PublicCloud var4 = this.publicCloudMgr.queryPublicCloudById(Long.valueOf(var2.getCloudId()));
         var10.put("cloudType", var4.getFlag());
         String var14;
         if((var14 = (new CloudOsCloud(this.cloudOSConnectionManager, var4)).getFlavorId(var3, var5, var7)) == null) {
            throw new AppException(5200);
         } else {
            var2.setFlavorRef(var14);
            var10.put("deployedDomain", var2);
            LoginInfo var15 = LocalUser.get();
            String var17 = var2.getImageName();
            String var18;
            if(StringUtils.isEmpty(var18 = var2.getMetadata().getAlias().trim())) {
               var2.getMetadata().setAlias(var2.getName());
               var18 = var2.getName();
            }

            String var6 = cloudosMng.getString("domainDeploy.operation", new Object[]{var18});
            String var19 = cloudosMng.getString("domainDeploy.operation.desc", new Object[]{var17, var18});
            RequestData var11 = new RequestData(47, var10, var15, var6, var18, Long.valueOf(var2.getCloudId()), var19);
            Long var12 = this.requestMgr.postRequest(var11);
            Long var16;
            if((var16 = Long.valueOf(var2.getOrgId())) != null) {
               this.orgParamertersHandler.applyOrgResources(var16, Integer.valueOf(1), Integer.valueOf(var2.getCpuNum()), Long.valueOf(var2.getMemNum()), Long.valueOf(var2.getDiskNum()));
            }

            RpcResult var13;
            (var13 = new RpcResult(var12)).setState(0);
            var13.setSuccessMessage(strMng.getString("domainDeploy.create.task.successMsg", new Object[]{var17}));
            return var13;
         }
      } catch (AppException var9) {
         ServerUtils.logAppException(log, var9);
         return new RpcResult(var9.getErrorMessage(), var9.getErrorCode());
      }
   }

   @RequestMapping(
      value = {"flavors"},
      method = {RequestMethod.GET}
   )
   public RpcResult queryFlavors(HttpSession var1, 
      @RequestParam(
         value = "cloudId",
         required = true
      ) Long var2, 
      @RequestParam(
         value = "miniCpu",
         required = false
      ) Integer var3, 
      @RequestParam(
         value = "miniMem",
         required = false
      ) Integer var4, 
      @RequestParam(
         value = "miniDisks",
         required = false
      ) Integer var5, 
      @RequestParam(
         value = "cpuNum",
         required = false
      ) Integer var6, 
      @RequestParam(
         value = "memNum",
         required = false
      ) Long var7, 
      @RequestParam(
         value = "diskNum",
         required = false
      ) Long var8) {
      HashMap var9 = Maps.newHashMap();
      if(var6 != null) {
         var9.put("cpuNum", var6);
      }

      if(var7 != null) {
         var9.put("memNum", var7);
      }

      if(var8 != null) {
         var9.put("diskNum", var8);
      }

      try {
         SessionValidator.validate(var1);
         CloudOSTemplet var11 = new CloudOSTemplet();
         if(var3 != null) {
            var11.setMinCpu(var3.intValue());
         }

         if(var4 != null) {
            var11.setMinRam(var4.intValue());
         }

         if(var5 != null) {
            var11.setMinDisk(var5.intValue());
         }

         PublicCloud var13 = this.publicCloudMgr.queryPublicCloudById(var2);
         List var12 = (new CloudOsCloud(this.cloudOSConnectionManager, var13)).queryFlavors(var11);
         return new RpcResult(var12);
      } catch (AppException var10) {
         ServerUtils.logAppException(log, var10);
         return new RpcResult(var10.getErrorMessage(), var10.getErrorCode());
      }
   }

   @RequestMapping(
      value = {"networks"},
      method = {RequestMethod.GET}
   )
   public RpcResult queryNetworks(HttpSession var1, 
      @RequestParam(
         value = "cloudId",
         required = true
      ) Long var2) {
      try {
         SessionValidator.validate(var1);
         PublicCloud var4 = this.publicCloudMgr.queryPublicCloudById(var2);
         List var5 = (new CloudOsCloud(this.cloudOSConnectionManager, var4)).queryNetworks();
         return new RpcResult(var5);
      } catch (AppException var3) {
         ServerUtils.logAppException(log, var3);
         return new RpcResult(var3.getErrorMessage(), var3.getErrorCode());
      }
   }

   @RequestMapping(
      value = {"azones"},
      method = {RequestMethod.GET}
   )
   public RpcResult queryAzones(HttpSession var1, 
      @RequestParam(
         value = "cloudId",
         required = true
      ) Long var2) {
      try {
         SessionValidator.validate(var1);
         PublicCloud var4 = this.publicCloudMgr.queryPublicCloudById(var2);
         List var5 = (new CloudOsCloud(this.cloudOSConnectionManager, var4)).queryAzones();
         return new RpcResult(var5);
      } catch (AppException var3) {
         ServerUtils.logAppException(log, var3);
         return new RpcResult(var3.getErrorMessage(), var3.getErrorCode());
      }
   }

}
